#
# spec file for package ghc-criterion-measurement
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name criterion-measurement
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.2.3.0
Release:        1.6
Summary:        Criterion measurement functionality and associated types
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base-compat-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}

%description
Measurement-related functionality extracted from Criterion, with minimal
dependencies. The rationale for this is to enable alternative analysis
front-ends.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Oct 27 2024 Peter Simons <psimons@suse.com>
- Update criterion-measurement to version 0.2.3.0.
  0.2.3.0
  * Drop support for pre-8.0 versions of GHC.
* Sun May 12 2024 Peter Simons <psimons@suse.com>
- Update criterion-measurement to version 0.2.2.0.
  0.2.2.0
  * Supporting building with all AArch64 platforms (not just Linux and macOS).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Feb 17 2023 Peter Simons <psimons@suse.com>
- Update criterion-measurement to version 0.2.1.0.
  0.2.1.0
  * Make the behavior of the benchmarking functions independent of the
    `-fspec-const-count` limit.
* Thu Aug 11 2022 Peter Simons <psimons@suse.com>
- Update criterion-measurement to version 0.2.0.0.
  0.2.0.0
  * Add a `measPeakMbAllocated` field to `Measured` for reporting maximum
    megabytes allocated. Naturally, this affects the behavior of `Measured`'s
    `{To,From}JSON` and `Binary` instances.
* Thu Aug  4 2022 Peter Simons <psimons@suse.com>
- Update criterion-measurement to version 0.1.4.0.
  0.1.4.0
  * Fix a bug that occurred with GHC 9.2.4 or later that would cause incorrect
    measurements.
* Sat Jul 10 2021 psimons@suse.com
- Update criterion-measurement to version 0.1.3.0.
  0.1.3.0
  * Change `criterion_rdtsc` to return `mach_absolute_time` on macOS. This is a
    portable way of returning the number of CPU cycles that works on both Intel-
    and ARM-based Macs.
  * Change `criterion_gettime` to use `clock_gettime_nsec_np` instead of
    `mach_absolute_time` on macOS. While `mach_absolute_time` has nanosecond
    resolution on Intel-based Macs, this is not the case on ARM-based Macs, so
    the previous `mach_absolute_time`-based implementation would return incorrect
    timing results on Apple silicon.
    There are two minor consequences of this change:
  * `criterion-measurement` now only supports macOS 10.02 or later, as that is
    the first version to have `clock_gettime_nsec_np`. As macOS 10.02 was
    released in 2002, this is unlikely to affect users, but please speak up if
    this is a problem for you.
  * As `clock_gettime_nsec_np` does not require any special initialization
    code, `criterion_inittime` is now a no-op on macOS. If you manually invoke
    the `getTime` function in your code, however, it is still important that
    you `initializeTime` beforehand, as this is still required for the Windows
    implementation to work correctly.
* Mon Apr 26 2021 psimons@suse.com
- Add criterion-measurement at version 0.1.2.0.
